@@ -24,7 +24,7 @@ subprocess.run(
         cmd,
         stdout=log_file,
         stderr=subprocess.STDOUT,
-        preexec_fn=os.setpgrp   
+        #preexec_fn=os.setpgrp   
     )
 log_file.close()
 
@@ -635,7 +635,9 @@ class FaceRecognitionEmbeddingUseCase(BaseProcessor):
             )
             self.logger.debug("Applied category filtering")
 
-        
+        print("------------------TILL TRACKER MS----------------------------")
+        print("LATENCY:",(time.time() - processing_start)*1000,"| Throughput fps:",(1.0 / (time.time() - processing_start)) if (time.time() - processing_start) > 0 else None)
+        print("------------------TILL TRACKER MS----------------------------")
         # Advanced tracking (BYTETracker-like) - only if enabled
         if config.enable_face_tracking:
             from ..advanced_tracker import AdvancedTracker
@@ -675,6 +677,10 @@ class FaceRecognitionEmbeddingUseCase(BaseProcessor):
         recognized_persons = {}
         current_frame_staff_details = {}
 
+        print("------------------TRACKER INIT END----------------------------")
+        print("LATENCY:",(time.time() - processing_start)*1000,"| Throughput fps:",(1.0 / (time.time() - processing_start)) if (time.time() - processing_start) > 0 else None)
+        print("------------------TRACKER INIT END----------------------------")
+
         # Process face recognition for each detection (if enabled)
         if config.enable_face_recognition:
             face_recognition_result = await self._process_face_recognition(
@@ -689,6 +695,10 @@ class FaceRecognitionEmbeddingUseCase(BaseProcessor):
                 detection["recognition_status"] = "disabled"
                 detection["enrolled"] = False
 
+        print("------------------FACE RECONG CONFIG ENABLED----------------------------")
+        print("LATENCY:",(time.time() - processing_start)*1000,"| Throughput fps:",(1.0 / (time.time() - processing_start)) if (time.time() - processing_start) > 0 else None)
+        print("------------------FACE RECONG CONFIG ENABLED----------------------------")
+
         # Update tracking state for total count per label
         self._update_tracking_state(processed_data)
 
@@ -721,6 +731,10 @@ class FaceRecognitionEmbeddingUseCase(BaseProcessor):
             current_recognized_count, current_unknown_count, recognized_persons
         ))
 
+        print("------------------TILL FACE RECOG SUMMARY----------------------------")
+        print("LATENCY:",(time.time() - processing_start)*1000,"| Throughput fps:",(1.0 / (time.time() - processing_start)) if (time.time() - processing_start) > 0 else None)
+        print("------------------TILL FACE RECOG SUMMARY----------------------------")
+
         # Add detections to the counting summary (standard pattern for detection use cases)
         # Ensure display label is present for UI (does not affect logic/counters)
         for _d in processed_data:
@@ -751,6 +765,12 @@ class FaceRecognitionEmbeddingUseCase(BaseProcessor):
             business_analytics_list[0] if business_analytics_list else {}
         )
         summary = summary_list[0] if summary_list else {}
+
+        print("------------------TILL TRACKING STATS----------------------------")
+        print("LATENCY:",(time.time() - processing_start)*1000,"| Throughput fps:",(1.0 / (time.time() - processing_start)) if (time.time() - processing_start) > 0 else None)
+        print("------------------TILL TRACKING STATS----------------------------")
+
+
         agg_summary = {
             str(frame_number): {
                 "incidents": incidents,
@@ -863,6 +883,7 @@ class FaceRecognitionEmbeddingUseCase(BaseProcessor):
         """Process face recognition for each detection with embeddings"""
 
         # Initialize face client only when needed and if credentials are available
+        st0=time.time()
         if not self.face_client:
             try:
                 self.face_client = self._get_facial_recognition_client(config)
@@ -872,6 +893,9 @@ class FaceRecognitionEmbeddingUseCase(BaseProcessor):
                 )
                 # No client available, return empty list (no results)
                 return []
+        print("------------------FACE RECOG CLIENT INIT----------------------------")
+        print("LATENCY:",(time.time() - st0)*1000,"| Throughput fps:",(1.0 / (time.time() - st0)) if (time.time() - st0) > 0 else None)
+        print("------------------FACE RECOG CLIENT INIT----------------------------")
 
         # Initialize unknown faces storage if not exists
         if not hasattr(self, "unknown_faces_storage"):
@@ -914,11 +938,16 @@ class FaceRecognitionEmbeddingUseCase(BaseProcessor):
         for detection in detections:
             
             # Process each detection sequentially with await to preserve order
+            st1=time.time()
             processed_detection = await self._process_face(
                 detection, current_frame, location, current_timestamp, config,
                 current_recognized_count, current_unknown_count, 
                 recognized_persons, current_frame_staff_details
             )
+            print("------------------WHOLE FACE RECOG PROCESSING DETECTION----------------------------")
+            print("LATENCY:",(time.time() - st1)*1000,"| Throughput fps:",(1.0 / (time.time() - st1)) if (time.time() - st1) > 0 else None)
+            print("------------------FACE RECOG PROCESSING DETECTION----------------------------")
+
             # Include both known and unknown faces in final detections (maintains original order)
             if processed_detection:
                 final_detections.append(processed_detection)
@@ -948,12 +977,16 @@ class FaceRecognitionEmbeddingUseCase(BaseProcessor):
     ) -> Dict:
 
         # Extract and validate embedding using EmbeddingManager
+        st2=time.time()
         detection, embedding = self.embedding_manager.extract_embedding_from_detection(detection)
         if not embedding:
             return None
 
         # Internal tracker-provided ID (from AdvancedTracker; ignore upstream IDs entirely)
         track_id = detection.get("track_id")
+        print("------------------FACE RECOG EMBEDDING EXTRACTION----------------------------")
+        print("LATENCY:",(time.time() - st2)*1000,"| Throughput fps:",(1.0 / (time.time() - st2)) if (time.time() - st2) > 0 else None)
+        print("------------------FACE RECOG EMBEDDING EXTRACTION----------------------------")
 
         # Determine if detection is eligible for recognition (similar to compare_similarity gating)
         bbox = detection.get("bounding_box", {}) or {}
@@ -1016,6 +1049,7 @@ class FaceRecognitionEmbeddingUseCase(BaseProcessor):
                         except Exception:
                             pass
                 else: #if eligible for recognition
+                    st3=time.time()
                     staff_id, person_name, similarity_score, employee_id, staff_details, detection_type = await self.temporal_identity_manager.update(
                         track_id=track_key,
                         emb=embedding,
@@ -1023,6 +1057,9 @@ class FaceRecognitionEmbeddingUseCase(BaseProcessor):
                         location=location,
                         timestamp=current_timestamp,
                     )
+                    print("------------------FACE RECOG TEMPORAL IDENTITY MANAGER UPDATE----------------------------")
+                    print("LATENCY:",(time.time() - st3)*1000,"| Throughput fps:",(1.0 / (time.time() - st3)) if (time.time() - st3) > 0 else None)
+                    print("------------------FACE RECOG TEMPORAL IDENTITY MANAGER UPDATE----------------------------")
         except Exception as e:
             self.logger.warning(f"TemporalIdentityManager update failed: {e}")
 
@@ -1096,14 +1133,22 @@ class FaceRecognitionEmbeddingUseCase(BaseProcessor):
                 and employee_id
                 and not str(employee_id).startswith("unknown_")
             ):
+                st4=time.time()
                 await self.people_activity_logging.enqueue_detection(
                     detection=detection,
                     current_frame=current_frame,
                     location=location,
                 )
+                print("------------------FACE RECOG ENQUEUEING DETECTION FOR ACTIVITY LOGGING----------------------------")
+                print("LATENCY:",(time.time() - st4)*1000,"| Throughput fps:",(1.0 / (time.time() - st4)) if (time.time() - st4) > 0 else None)
+                print("------------------FACE RECOG ENQUEUEING DETECTION FOR ACTIVITY LOGGING----------------------------")
+
                 self.logger.debug(f"Enqueued known face detection for activity logging: {detection.get('person_name', 'Unknown')}")
         except Exception as e:
             self.logger.error(f"Error enqueueing detection for activity logging: {e}")
+        print("------------------FACE RECOG ENQUEUEING DETECTION FOR ACTIVITY LOGGING----------------------------")
+        print("LATENCY:",(time.time() - st2)*1000,"| Throughput fps:",(1.0 / (time.time() - st2)) if (time.time() - st2) > 0 else None)
+        print("------------------FACE RECOG ENQUEUEING DETECTION FOR ACTIVITY LOGGING----------------------------")
 
         return detection
 
@@ -1743,56 +1788,57 @@ class FaceRecognitionEmbeddingUseCase(BaseProcessor):
         return f"{hours:02d}:{minutes:02d}:{seconds:.1f}"
 
     def _format_timestamp(self, timestamp: Any) -> str:
-        """Format a timestamp so that exactly two digits follow the decimal point (milliseconds).
+        """Format a timestamp to match the current timestamp format: YYYY:MM:DD HH:MM:SS.
 
         The input can be either:
-        1. A numeric Unix timestamp (``float`` / ``int``) – it will first be converted to a
-           string in the format ``YYYY-MM-DD-HH:MM:SS.ffffff UTC``.
-        2. A string already following the same layout.
+        1. A numeric Unix timestamp (``float`` / ``int``) – it will be converted to datetime.
+        2. A string in the format ``YYYY-MM-DD-HH:MM:SS.ffffff UTC``.
 
-        The returned value preserves the overall format of the input but truncates or pads
-        the fractional seconds portion to **exactly two digits**.
+        The returned value will be in the format: YYYY:MM:DD HH:MM:SS (no milliseconds, no UTC suffix).
 
         Example
         -------
-        >>> self._format_timestamp("2025-08-19-04:22:47.187574 UTC")
-        '2025-08-19-04:22:47.18 UTC'
+        >>> self._format_timestamp("2025-10-27-19:31:20.187574 UTC")
+        '2025:10:27 19:31:20'
         """
 
-        # Convert numeric timestamps to the expected string representation first
+        # Convert numeric timestamps to datetime first
         if isinstance(timestamp, (int, float)):
-            timestamp = datetime.fromtimestamp(timestamp, timezone.utc).strftime(
-                '%Y-%m-%d-%H:%M:%S.%f UTC'
-            )
+            dt = datetime.fromtimestamp(timestamp, timezone.utc)
+            return dt.strftime('%Y:%m:%d %H:%M:%S')
 
         # Ensure we are working with a string from here on
         if not isinstance(timestamp, str):
             return str(timestamp)
 
-        # If there is no fractional component, simply return the original string
-        if '.' not in timestamp:
-            return timestamp
+        # Remove ' UTC' suffix if present
+        timestamp_clean = timestamp.replace(' UTC', '').strip()
 
-        # Split out the main portion (up to the decimal point)
-        main_part, fractional_and_suffix = timestamp.split('.', 1)
+        # Remove milliseconds if present (everything after the last dot)
+        if '.' in timestamp_clean:
+            timestamp_clean = timestamp_clean.split('.')[0]
 
-        # Separate fractional digits from the suffix (typically ' UTC')
-        if ' ' in fractional_and_suffix:
-            fractional_part, suffix = fractional_and_suffix.split(' ', 1)
-            suffix = ' ' + suffix  # Re-attach the space removed by split
-        else:
-            fractional_part, suffix = fractional_and_suffix, ''
+        # Parse the timestamp string and convert to desired format
+        try:
+            # Handle format: YYYY-MM-DD-HH:MM:SS
+            if timestamp_clean.count('-') >= 2:
+                # Replace first two dashes with colons for date part, third with space
+                parts = timestamp_clean.split('-')
+                if len(parts) >= 4:
+                    # parts = ['2025', '10', '27', '19:31:20']
+                    formatted = f"{parts[0]}:{parts[1]}:{parts[2]} {'-'.join(parts[3:])}"
+                    return formatted
+        except Exception:
+            pass
 
-        # Guarantee exactly two digits for the fractional part
-        fractional_part = (fractional_part + '00')[:2]
-
-        return f"{main_part}.{fractional_part}{suffix}"
+        # If parsing fails, return the cleaned string as-is
+        return timestamp_clean
 
     def _get_current_timestamp_str(self, stream_info: Optional[Dict[str, Any]], precision=False, frame_id: Optional[str]=None) -> str:
         """Get formatted current timestamp based on stream type."""
+        
         if not stream_info:
             return "00:00:00.00"
-
         if precision:
             if stream_info.get("input_settings", {}).get("start_frame", "na") != "na":
                 if frame_id:
@@ -1801,7 +1847,6 @@ class FaceRecognitionEmbeddingUseCase(BaseProcessor):
                     start_time = stream_info.get("input_settings", {}).get("start_frame", 30)/stream_info.get("input_settings", {}).get("original_fps", 30)
                 stream_time_str = self._format_timestamp_for_video(start_time)
                 
-
                 return self._format_timestamp(stream_info.get("input_settings", {}).get("stream_time", "NA"))
             else:
                 return datetime.now(timezone.utc).strftime("%Y-%m-%d-%H:%M:%S.%f UTC")
@@ -1813,7 +1858,8 @@ class FaceRecognitionEmbeddingUseCase(BaseProcessor):
                 start_time = stream_info.get("input_settings", {}).get("start_frame", 30)/stream_info.get("input_settings", {}).get("original_fps", 30)
 
             stream_time_str = self._format_timestamp_for_video(start_time)
-            
+           
+
             return self._format_timestamp(stream_info.get("input_settings", {}).get("stream_time", "NA"))
         else:
             stream_time_str = stream_info.get("input_settings", {}).get("stream_info", {}).get("stream_time", "")
@@ -1835,23 +1881,57 @@ class FaceRecognitionEmbeddingUseCase(BaseProcessor):
         
         if precision:
             if self.start_timer is None:
-                self.start_timer = stream_info.get("input_settings", {}).get("stream_time", "NA")
+                candidate = stream_info.get("input_settings", {}).get("stream_time")
+                if not candidate or candidate == "NA":
+                    candidate = datetime.now(timezone.utc).strftime("%Y-%m-%d-%H:%M:%S.%f UTC")
+                self.start_timer = candidate
                 return self._format_timestamp(self.start_timer)
             elif stream_info.get("input_settings", {}).get("start_frame", "na") == 1:
-                self.start_timer = stream_info.get("input_settings", {}).get("stream_time", "NA")
+                candidate = stream_info.get("input_settings", {}).get("stream_time")
+                if not candidate or candidate == "NA":
+                    candidate = datetime.now(timezone.utc).strftime("%Y-%m-%d-%H:%M:%S.%f UTC")
+                self.start_timer = candidate
                 return self._format_timestamp(self.start_timer)
             else:
                 return self._format_timestamp(self.start_timer)
 
         if self.start_timer is None:
-            self.start_timer = stream_info.get("input_settings", {}).get("stream_time", "NA")
+            # Prefer direct input_settings.stream_time if available and not NA
+            candidate = stream_info.get("input_settings", {}).get("stream_time")
+            if not candidate or candidate == "NA":
+                # Fallback to nested stream_info.stream_time used by current timestamp path
+                stream_time_str = stream_info.get("input_settings", {}).get("stream_info", {}).get("stream_time", "")
+                if stream_time_str:
+                    try:
+                        timestamp_str = stream_time_str.replace(" UTC", "")
+                        dt = datetime.strptime(timestamp_str, "%Y-%m-%d-%H:%M:%S.%f")
+                        self._tracking_start_time = dt.replace(tzinfo=timezone.utc).timestamp()
+                        candidate = datetime.fromtimestamp(self._tracking_start_time, timezone.utc).strftime("%Y-%m-%d-%H:%M:%S.%f UTC")
+                    except:
+                        candidate = datetime.now(timezone.utc).strftime("%Y-%m-%d-%H:%M:%S.%f UTC")
+                else:
+                    candidate = datetime.now(timezone.utc).strftime("%Y-%m-%d-%H:%M:%S.%f UTC")
+            self.start_timer = candidate
             return self._format_timestamp(self.start_timer)
         elif stream_info.get("input_settings", {}).get("start_frame", "na") == 1:
-            self.start_timer = stream_info.get("input_settings", {}).get("stream_time", "NA")
+            candidate = stream_info.get("input_settings", {}).get("stream_time")
+            if not candidate or candidate == "NA":
+                stream_time_str = stream_info.get("input_settings", {}).get("stream_info", {}).get("stream_time", "")
+                if stream_time_str:
+                    try:
+                        timestamp_str = stream_time_str.replace(" UTC", "")
+                        dt = datetime.strptime(timestamp_str, "%Y-%m-%d-%H:%M:%S.%f")
+                        ts = dt.replace(tzinfo=timezone.utc).timestamp()
+                        candidate = datetime.fromtimestamp(ts, timezone.utc).strftime("%Y-%m-%d-%H:%M:%S.%f UTC")
+                    except:
+                        candidate = datetime.now(timezone.utc).strftime("%Y-%m-%d-%H:%M:%S.%f UTC")
+                else:
+                    candidate = datetime.now(timezone.utc).strftime("%Y-%m-%d-%H:%M:%S.%f UTC")
+            self.start_timer = candidate
             return self._format_timestamp(self.start_timer)
         
         else:
-            if self.start_timer is not None:
+            if self.start_timer is not None and self.start_timer != "NA":
                 return self._format_timestamp(self.start_timer)
 
             if self._tracking_start_time is None:
